package loginTest;

import base.BaseTest;
import dataprovider.DataProviderClass;
import org.testng.annotations.Test;

import static org.testng.Assert.*;

public class LoginTestClass extends BaseTest {

    @Test(description = "Verify that username field is visible",
            groups = {"LoginUI"},
            priority = 1)
    public void UsernameFieldVisibility() {
        boolean isDisplayed = homePageLogin.getUserNameElement().isDisplayed();
        assertTrue(isDisplayed, "Username field is not visible");
    }

    @Test(description = "Verify that username field is clickable",
            groups = {"LoginUI"},
            dependsOnMethods = {"UsernameFieldVisibility"},
            priority = 2)
    public void UsernameFieldInteraction() {
        boolean isInteract = homePageLogin.getUserNameElement().isEnabled();
        assertTrue(isInteract, "Username field is not getting input");
    }
    //-----------------------------------------------------//

    @Test(description = "Verify that Password field is visible",
            groups = {"LoginUI"},
            priority = 3)
    public void PasswordFieldVisibility() {
        boolean isDisplayed = homePageLogin.getPasswordElement().isDisplayed();
        assertTrue(isDisplayed, "Password field is not visible");
    }

    @Test(description = "Verify that Password field is clickable",
            groups = {"LoginUI"},
            dependsOnMethods = {"PasswordFieldVisibility"},
            priority = 4)
    public void PasswordFieldInteraction() {
        boolean isInteract = homePageLogin.getPasswordElement().isEnabled();
        assertTrue(isInteract, "Password field is not getting input");
    }

    //------------------------------------------------------------

    @Test(description = "Verify that Login button is visible",
            groups = {"LoginUI"},
            priority = 5)
    public void LoginButtonVisibility() {
        boolean isDisplayed = homePageLogin.getLoginButtonElement().isDisplayed();
        assertTrue(isDisplayed, "Login button is not visible");
    }

    @Test(description = "Verify that Login button is clickable",
            groups = {"LoginUI"},
            dependsOnMethods = {"LoginButtonVisibility"},
            priority = 6)
    public void LoginButtonInteraction() {
        boolean isInteract = homePageLogin.getLoginButtonElement().isEnabled();
        assertTrue(isInteract, "Login button is not clickable");
    }


    @Test(description = "Verify login is successful with valid credentials",
            priority = 7,
            //dependsOnGroups = {"LoginUI"},
            dataProvider = "loginData", dataProviderClass = DataProviderClass.class)
    public void testLogin(String username, String password) {
        homePageLogin.setUserName(username);
        homePageLogin.setPassword(password);
        homePageLogin.clickLogin();
        assertEquals(homePageLogin.getCurrentUrl(), "https://opensource-demo.orangehrmlive.com/web/index.php/dashboard/index", "Login is not successful");
        clearCookies();

    }
}
